# configuration options for the server (murmur)
%define build_server	1
%define build_web	1
%define build_ice	1
# configuration options for the client
%define build_client	1
%define build_speechd	1
%define build_g15	1

%{?_without_server:	%{expand: %%global build_server 0}}
%{?_without_server:	%{expand: %%global build_ice 0}}
%{?_with_server:	%{expand: %%global build_server 1}}

%{?_without_ice:	%{expand: %%global build_ice 0}}
%{?_with_ice:		%{expand: %%global build_ice 1}}

%{?_without_client:	%{expand: %%global build_client 0}}
%{?_without_client:	%{expand: %%global build_speechd 0}}
%{?_without_client:	%{expand: %%global build_g15 0}}
%{?_with_client:	%{expand: %%global build_client 1}}

%{?_without_speechd:	%{expand: %%global build_speechd 0}}
%{?_with_speechd:	%{expand: %%global build_speechd 1}}

%{?_without_g15:	%{expand: %%global build_g15 0}}
%{?_with_g15:		%{expand: %%global build_g15 1}}

# comment out if not a pre-release
#define prel	rc1
# bump the rel
%define rel	4

Summary:	Low-latency, high-quality voice communication for gamers
Name:		mumble
Version:	1.3.3
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	BSD
Group:		Communications/Telephony
Url:		http://mumble.sourceforge.net/
Source0:	https://github.com/mumble-voip/mumble/releases/download/%{version}%{?prel:-%prel}/%{name}-%{version}%{?prel:-%prel}.tar.gz
# conf files courtesy of debian package
Source1:	%{name}-server.ini
Source2:	%{name}-server-web.conf
Source3:	MurmurPHP.ini
Source4:	README.install.urpmi.mumble-server-web
Source5:	%{name}-server-init.mdv
Source6:	%{name}-server.logrotate
Source7:	%{name}-tmpfiles.conf
Patch0:		mumble-1.3.0-mga-celt071_include_dir.patch
# Fix broken logrotate script (start-stop-daemon not available anymore), BZ 730129
Patch1:		mumble-1.2.3-fdr-logrotate.patch
# Fix broken celt-0.11.3 (uncompatible with mumble) mga#12853
Patch2:		mumble-1.3.0-mga-only-use-celt071-libnames.patch
Patch3:		mumble-1.3.0-mga-celt071-AudioInput.patch
# Upstream patches

BuildConflicts:	celt-devel >= 0.7.0
BuildRequires:	desktop-file-utils
BuildRequires:	kf5-macros
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Sql)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	boost-devel
BuildRequires:	protobuf-compiler
BuildRequires:	pkgconfig(avahi-compat-libdns_sd)
BuildRequires:	pkgconfig(grpc)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	pkgconfig(speex) >= 1.2
BuildRequires:	pkgconfig(speexdsp)
BuildRequires:	pkgconfig(celt071)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(xevie)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(opus)
BuildRequires:	pkgconfig(xi) >= 1.6.0

%if %build_speechd
BuildRequires:	pkgconfig(speech-dispatcher)
%endif

%if %build_g15
BuildRequires:	g15daemon_client-devel
%endif

# (cg) The celt libraries are loaded dynamically but we need at least 0.7.1 to
# be compatible with the Windows and OSX clients
# The 0.11 version can work if the clients (and presumably the server) all
# support it.
# Using mklibname is not ideal but it's the easiest option for now
Requires:	%{mklibname celt 071 0}

Requires:	qt5-database-plugin-sqlite
Requires:	%{name}-plugins = %{version}-%{release}
Recommends:	%{name}-protocol-plasma5

%if %build_speechd
Recommends:	speech-dispatcher
%endif

%if %build_g15
Recommends:	g15daemon
%endif

%description
Low-latency, high-quality voice communication for gamers.

Includes game linking, so voice from other players comes
from the direction of their characters, and has echo
cancellation so the sound from your loudspeakers won't be
audible to other players.

%package	protocol-plasma5
Summary:	The mumble protocol for Plasma5
Group:		Graphical desktop/KDE
Requires:	%{name} = %{version}-%{release}
# keep just protocol for plasma5 (kde4 is dead)
Obsoletes:	mumble-protocol-kde4

%description	protocol-plasma5
The mumble protocol for Plasma5.

%package	plugins
Summary:	Mumble plugins
Group:		Communications/Telephony
Requires:	%{name} = %{version}-%{release}

%description	plugins
This packages provides the Mumble plugins.

%if %build_server
%package	server
Summary:	Murmur, the VOIP server for Mumble
Group:		Communications/Telephony
Requires(post):	systemd >= %{systemd_required_version}
Requires(pre):	rpm-helper
Requires(post):	rpm-helper
Requires(preun):	rpm-helper
%if %build_ice
# keep ice-devel, pkgconfig(ice) is not the same ice devel pkg
BuildRequires:	ice-devel
# (cg) ice-devel should require this itself, but it doesn't...
BuildRequires:	ice
%endif
Requires:	qt5-database-plugin-sqlite
Requires:	dbus
%if !%build_web
Conflicts:	%{name}-server-web
%endif

%description	server
This package provides Murmur, the VOIP server for Mumble.

%if %build_web
%package	server-web
Summary:	Web scripts for mumble-server
Group:		Communications/Telephony
Requires:	apache
Requires:	perl-CGI
Requires:	mail-server
%if %build_ice
Requires:	ice
%endif
Requires:	%{name}-server = %{version}-%{release}

%description	server-web
This package contains the web scripts for mumble-server.

%endif
%endif

%prep
%setup -q
%autopatch -p1

cp -p %{SOURCE4} README.install.urpmi

%build
%qmake_qt5 main.pro \
%if %build_server == 0
	CONFIG+=no-server \
%endif
%if %build_ice == 0
	CONFIG+=no-ice \
%endif
%if %build_client == 0
	CONFIG+=no-client \
%endif
%if %build_speechd == 0
	CONFIG+=no-speechd \
%endif
%if %build_g15 == 0
	CONFIG+=no-g15 \
%endif
	CONFIG+=grpc \
	CONFIG+=no-bundled-speex \
	CONFIG+=no-bundled-celt \
	CONFIG+=no-bundled-opus \
	CONFIG+=no-embed-qt-translations \
	CONFIG+=no-update \
	DEFINES+=PLUGIN_PATH=%{_libdir}/%{name} \
	DEFINES+=DEFAULT_SOUNDSYSTEM=PulseAudio

%{_qt5_bindir}/lrelease src/mumble/*.ts
%make_build

%install
%if %build_client
# --- Mumble install ---

install -D -m 0755 release/%{name} %{buildroot}%{_bindir}/%{name}
install -m 0755 scripts/%{name}-overlay %{buildroot}%{_bindir}/%{name}-overlay
install -D -m 0644 scripts/%{name}.protocol %{buildroot}%{_kf5_services}/%{name}.protocol
install -d -m 0755 %{buildroot}%{_libdir}/%{name}/plugins
cp -pr release/libmumble* %{buildroot}%{_libdir}/%{name}/
cp -pr release/plugins/liblink.so %{buildroot}%{_libdir}/%{name}/

# Mumble icons
install -D -m 0644 icons/%{name}.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

# Mumble desktop file
install -d -m 0755 %{buildroot}%{_datadir}/applications
install -m 0644 scripts/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
desktop-file-install \
		     --remove-category="Qt" \
		     --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/*

# translations
mkdir -p %{buildroot}%{_datadir}/%{name}/translations
install -m 0644 src/%{name}/*.qm %{buildroot}%{_datadir}/%{name}/translations/
%endif

%if %build_server
# --- Mumble-server/Murmur install ---

install -D -m 0755 release/murmurd "%{buildroot}%{_sbindir}/murmurd"
install -D -m 0755 scripts/murmur-user-wrapper %{buildroot}%{_bindir}/murmur-user-wrapper
mkdir -p %{buildroot}%{_sysconfdir}/{dbus-1/system.d,logrotate.d}
install -m 0644 scripts/murmur.conf %{buildroot}%{_sysconfdir}/dbus-1/system.d/%{name}-server.conf
install -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}-server
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}-server.ini

%if %build_ice
# install Mumur.ice  in /usr/share/slice
install -D -m 0755 src/murmur/Murmur.ice %{buildroot}%{_datadir}/slice/Murmur.ice
%endif

# install initscript
mkdir -p %{buildroot}%{_initrddir}
install -m 0744 %{SOURCE5} %{buildroot}%{_initrddir}/%{name}-server

# create database directory
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/%{name}-server

# create log directory
install -d -m 0755 %{buildroot}%{_localstatedir}/log/%{name}-server

# create tmpfiles directory
install -D -p -m 0644 %{SOURCE7} %{buildroot}%{_tmpfilesdir}/%{name}-server.conf

# install example
mkdir -p %{buildroot}%{_localstatedir}/%{name}-server/examples

# create pidfile directory
install -d -m 0755 %{buildroot}%{_rundir}/%{name}-server

%if %build_web
# --- Mumble-server-web files ---
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/httpd/conf.d/%{name}-server-web.conf
%if %build_ice
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/php.d/MurmurPHP.ini
install -D -m 0644 scripts/server/ice/weblist.php %{buildroot}%{_datadir}/%{name}-server-web/www/weblist.php
%endif
install -D -m 0755 scripts/server/dbus/weblist.pl %{buildroot}%{_datadir}/%{name}-server-web/www/weblist.cgi
install -D -m 0755 scripts/server/dbus/murmur.pl %{buildroot}%{_datadir}/%{name}-server-web/www/register.cgi
pushd %{buildroot}%{_datadir}/%{name}-server-web/www
ln -s weblist.php index.php
popd
%endif
%endif

# --- Manpages ---
install -d -m 0755 %{buildroot}%{_mandir}/man1
%if %build_server
install -m 0644 man/murmur* %{buildroot}%{_mandir}/man1
%endif
%if %build_client
install -m 0644 man/mumble* %{buildroot}%{_mandir}/man1
%endif

%if %build_server
%pre server
%_pre_useradd %{name}-server %{_var}/lib/%{name}-server /bin/sh

%post server
%_tmpfilescreate %{_tmpfilesdir}/%{name}-server
%_post_service %{name}-server

%preun server
%_preun_service %{name}-server

%postun server
%_postun_userdel %{name}-server
%endif


%if %build_client
%files
%doc README README.Linux CHANGES LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}-overlay
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.svg
%{_mandir}/man1/%{name}.*
%{_mandir}/man1/%{name}-overlay.*

%files protocol-plasma5
%{_kf5_services}/%{name}.protocol

%files plugins
%{_libdir}/%{name}
%endif

%if %build_server
%files server
%if %build_client == 0
%doc README README.Linux CHANGES LICENSE
%endif
%doc scripts/murmur.ini
%{_bindir}/murmur-user-wrapper
%{_sbindir}/murmurd
%{_initrddir}/%{name}-server
%{_tmpfilesdir}/%{name}-server.conf
%config(noreplace) %{_sysconfdir}/%{name}-server.ini
%{_sysconfdir}/logrotate.d/%{name}-server
%{_sysconfdir}/dbus-1/system.d/%{name}-server.conf
%attr(-,mumble-server,mumble-server) %dir %{_localstatedir}/lib/%{name}-server
%attr(-,mumble-server,root) %dir %{_localstatedir}/log/%{name}-server
%attr(-,mumble-server,mumble-server) %ghost %dir %{_rundir}/%{name}-server
%if %build_ice
%{_datadir}/slice/Murmur.ice
%endif
%{_mandir}/man1/murmur-user-wrapper.*
%{_mandir}/man1/murmurd.*

%if %build_web
%files server-web
%doc README.install.urpmi
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}-server-web.conf
%if %build_ice
%config(noreplace) %{_sysconfdir}/php.d/MurmurPHP.ini
%endif
%{_datadir}/%{name}-server-web
%endif
%endif


%changelog
* Fri Dec 18 2020 luigiwalser <luigiwalser> 1.3.3-4.mga8
+ Revision: 1660988
- rebuild for protobuf

* Thu Dec 17 2020 umeabot <umeabot> 1.3.3-3.mga8
+ Revision: 1659064
- Rebuild for new Qt5

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1.3.3-2.mga8
+ Revision: 1650539
- rebuild for protobuf

* Thu Oct 08 2020 daviddavid <daviddavid> 1.3.3-1.mga8
+ Revision: 1632767
- new version: 1.3.3

* Sun Jul 12 2020 daviddavid <daviddavid> 1.3.2-1.mga8
+ Revision: 1605457
- new version: 1.3.2

* Tue Jun 30 2020 daviddavid <daviddavid> 1.3.1-3.mga8
+ Revision: 1600754
- rebuild for new grpc 1.30.0

* Sun Jun 28 2020 daviddavid <daviddavid> 1.3.1-2.mga8
+ Revision: 1600174
- rebuild for new protobuf 3.12.3

* Tue Jun 09 2020 daviddavid <daviddavid> 1.3.1-1.mga8
+ Revision: 1591112
- new version: 1.3.1

* Thu Apr 16 2020 daviddavid <daviddavid> 1.3.1-0.rc1.2.mga8
+ Revision: 1567853
- use the official/merged upstream build fix

* Wed Apr 15 2020 daviddavid <daviddavid> 1.3.1-0.rc1.1.mga8
+ Revision: 1567534
- new version: 1.3.1-rc1

* Tue Mar 31 2020 pterjan <pterjan> 1.3.0-6.mga8
+ Revision: 1562477
- Rebuild for new ice

* Mon Mar 30 2020 daviddavid <daviddavid> 1.3.0-5.mga8
+ Revision: 1562370
- rebuild for missing package (mga#26391)

* Tue Feb 18 2020 umeabot <umeabot> 1.3.0-4.mga8
+ Revision: 1541113
- Mageia 8 Mass Rebuild

* Thu Dec 19 2019 daviddavid <daviddavid> 1.3.0-3.mga8
+ Revision: 1468997
- rebuild for new grpc 1.26.0

* Thu Dec 19 2019 daviddavid <daviddavid> 1.3.0-2.mga8
+ Revision: 1468852
- rebuild for new protobuf 3.11.2

* Mon Nov 11 2019 daviddavid <daviddavid> 1.3.0-1.mga8
+ Revision: 1459169
- new version: 1.3.0 (final)

* Sun Jun 30 2019 daviddavid <daviddavid> 1.3.0-0.rc2.1.mga8
+ Revision: 1416365
- new version: 1.3.0-rc2 (second Qt5 port)

* Wed Apr 03 2019 daviddavid <daviddavid> 1.3.0-0.rc1.1.mga7
+ Revision: 1385526
- new version: 1.3.0-rc1 (first Qt5 port)
- port to Qt5
- enable gRPC support
- reenable ice support
- keep only protocol for plasma5 (kde4 is dead)
- remove some merged upstream patches
- update some conf files to use /run instead of /var/run

* Tue Apr 02 2019 mrambo3501 <mrambo3501> 1.2.19-7.mga7
+ Revision: 1385397
- add debian patch which fixes CVE-2018-20743 (mga#24479)

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1.2.19-6.mga7
+ Revision: 1346159
- rebuild for protobuf

* Sun Sep 23 2018 umeabot <umeabot> 1.2.19-5.mga7
+ Revision: 1299648
- Mageia 7 Mass Rebuild

* Sun Apr 15 2018 daviddavid <daviddavid> 1.2.19-4.mga7
+ Revision: 1218996
- rebuild for new protobuf 3.5

* Tue Jan 16 2018 daviddavid <daviddavid> 1.2.19-3.mga7
+ Revision: 1193728
- add upstream patch to fix AudioOutput to use the float overload of std::abs

* Fri Sep 01 2017 daviddavid <daviddavid> 1.2.19-2.mga7
+ Revision: 1150415
- rebuild for new openssl 1.1.0f

* Sun Jan 29 2017 daviddavid <daviddavid> 1.2.19-1.mga6
+ Revision: 1084102
- new version: 1.2.19

* Fri Dec 16 2016 daviddavid <daviddavid> 1.2.18-1.mga6
+ Revision: 1075707
- new version: 1.2.18

* Sun Sep 25 2016 daviddavid <daviddavid> 1.2.17-2.mga6
+ Revision: 1056034
- new version: 1.2.17
- add the protocol support for Plasma5

* Fri May 06 2016 daviddavid <daviddavid> 1.2.16-1.mga6
+ Revision: 1009677
- new version: 1.2.16

* Mon Mar 07 2016 daviddavid <daviddavid> 1.2.15-1.mga6
+ Revision: 986948
- new version: 1.2.15

* Thu Mar 03 2016 daviddavid <daviddavid> 1.2.14-1.mga6
+ Revision: 984916
- new version: 1.2.14

* Wed Mar 02 2016 umeabot <umeabot> 1.2.13-2.mga6
+ Revision: 983773
- Rebuild for openssl

* Sun Jan 10 2016 daviddavid <daviddavid> 1.2.13-1.mga6
+ Revision: 921222
- new version: 1.2.13

* Mon Dec 21 2015 daviddavid <daviddavid> 1.2.12-1.mga6
+ Revision: 913202
- new version: 1.2.12
- use now upstream github Source URL

* Mon Dec 07 2015 daviddavid <daviddavid> 1.2.11-1.mga6
+ Revision: 908648
- new version: 1.2.11 (fixes CVE-2015-1794)
  * http://blog.mumble.info/mumble-1-2-11/

* Wed Oct 14 2015 daviddavid <daviddavid> 1.2.10-4.mga6
+ Revision: 891642
- add BR on pkgconfig(speexdsp) (fix build)

* Fri Sep 25 2015 daviddavid <daviddavid> 1.2.10-3.mga6
+ Revision: 883464
- rebuild for new boost-1.59.0

* Fri Aug 28 2015 cjw <cjw> 1.2.10-2.mga6
+ Revision: 870726
- rebuild with gcc 5

* Sun Jul 26 2015 daviddavid <daviddavid> 1.2.10-1.mga6
+ Revision: 857796
- new version: 1.2.10 (fixes CVE-2015-1793)
  * http://blog.mumble.info/mumble-1-2-10/

* Sat Jun 20 2015 daviddavid <daviddavid> 1.2.9-1.mga6
+ Revision: 836123
- new version: 1.2.9
- remove merged upstream Patch4 (compile-fix.patch)

* Tue Feb 24 2015 daviddavid <daviddavid> 1.2.8-5.mga5
+ Revision: 816809
- fix broken celt-0.11.3 as it is not compatible with mumble (mga#12853)
  * remove lib(64)celt0_2 as a recommends
- rename Patch1 for celt071
- fix opus build that was not unbundled and also not enabled (mga#11453)

* Wed Oct 15 2014 umeabot <umeabot> 1.2.8-4.mga5
+ Revision: 739646
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.8-3.mga5
+ Revision: 682695
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Mon Sep 01 2014 luigiwalser <luigiwalser> 1.2.8-2.mga5
+ Revision: 670349
- rebuild for protobuf

* Thu Aug 14 2014 daviddavid <daviddavid> 1.2.8-1.mga5
+ Revision: 662522
- remove unneeded upstream patch as it is now fixed
  * 0001-bonjour-use-Qt-AutoConnection-for-BonjourServiceReso.patch
- fix an issue with the compilation of available languages
  * we need to compile all languages before %%make
- new version: 1.2.8

* Tue Jun 17 2014 daviddavid <daviddavid> 1.2.7-1.mga5
+ Revision: 637836
- new version: 1.2.7

* Thu May 15 2014 daviddavid <daviddavid> 1.2.6-1.mga5
+ Revision: 622924
- add patch from fedora to fix an compile error with g++ 4.9.1 (since g++ 4.9.0)
- new version: 1.2.6
  * update fixes CVE-2014-3755 and CVE-2014-3756 (mga#13382)
  * http://openwall.com/lists/oss-security/2014/05/15/4

* Sun May 11 2014 daviddavid <daviddavid> 1.2.5-1.mga5
+ Revision: 621970
- fix build with %%ghost (required for tmpfs)
- remove unneeded Provides/Obsoletes libraries (still remains from Mandriva)
- new version:1.2.5
  * update fixes CVE-2014-0044 (BZ 1061857) and CVE-2014-0045 (BZ 1061858)
- remove old/unneeded patches
- add 5 patches from fedora
- enable web build service (again compatible on this version)
- add manually missing translations
- add pidfile directory
- add some BRs (opus, xi, desktop-file-utils)
- Obsolete mumble-11x (removed upstream)
- update link url for Source0
- update License
- fix permission on mumble.protocol file
- prefer use pckgconfig for BRs

* Tue Dec 31 2013 dmorgan <dmorgan> 1.2.3-14.mga4
+ Revision: 563516
- Rebuild against current protobuf

* Wed Nov 27 2013 colin <colin> 1.2.3-13.mga4
+ Revision: 553734
- Switch to using apply_patches macro for easier management
- Build with speech-dispatcher 0.8
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ fwang <fwang>
- rebuild for new boost

* Tue Mar 26 2013 colin <colin> 1.2.3-10.mga3
+ Revision: 405312
- Disable web+ice support for now (incompatible ice version)

* Sun Mar 24 2013 colin <colin> 1.2.3-9.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sat Jan 12 2013 umeabot <umeabot> 1.2.3-8.mga3
+ Revision: 360498
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 10 2013 barjac <barjac> 1.2.3-7.mga3
+ Revision: 344511
- update group
- remove unneeded patch
- remove restriction on ice version
+ colin <colin>
- Fix group
- Tidy up service and tmpfiles related stuff
- Drop reload of messagebus (it shouldn't be needed these days)
- Add patches to allow working with ice < 3.4 (avoids bogus auto-requires)
- Fix path for some ice related files.
- Conflict with the -server-web package when not building it to ensure smooth upgrades
+ stormi <stormi>
- fix php-ice include path for Murmur

* Tue Jun 26 2012 colin <colin> 1.2.3-4.mga3
+ Revision: 264068
- Fix permissions on database file (mga#6511 CVE-2012-0863)
- Do not package /var/run/ folders (use systemd-tmpfiles instead)
- Add Requires(pre) rpm-helper for useradd helper

* Tue Jun 26 2012 colin <colin> 1.2.3-3.mga3
+ Revision: 263880
- Ensure the appropriate celt libraries are required/suggested
- Find libcelt 0.7.1 library with Mageia libname magling

* Sat Nov 19 2011 wally <wally> 1.2.3-2.mga2
+ Revision: 169142
- rebuild for new protobuf
- build against system celt 0.7.1
- add buildconflicts for newer celt to ensure we build against celt 0.7.1
+ dmorgan <dmorgan>
- Do not build the server-web package for now, we miss dependancies
- Remove BuildRoot
  Remove %%clean section

* Sun Jul 10 2011 kharec <kharec> 1.2.3-1.mga2
+ Revision: 121688
- rediff patches
- new version 1.2.3

* Mon Mar 28 2011 ennael <ennael> 1.2.2-3.mga1
+ Revision: 78293
- clean spec file
- imported package mumble


* Mon Dec 06 2010 Oden Eriksson <oeriksson@mandriva.com> 1.2.2-3mdv2011.0
+ Revision: 612967
- the mass rebuild of 2010.1 packages

* Mon Apr 19 2010 Funda Wang <fwang@mandriva.org> 1.2.2-2mdv2010.1
+ Revision: 536611
- fix linkage

* Sat Feb 20 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.2.2-1mdv2010.1
+ Revision: 508809
- update to new version 1.2.2
- drop patch 1

* Sun Jan 31 2010 Jérôme Brenier <incubusss@mandriva.org> 1.2.1-2mdv2010.1
+ Revision: 498747
- rebuild for new protobuf

* Sun Jan 10 2010 Jérôme Brenier <incubusss@mandriva.org> 1.2.1-1mdv2010.1
+ Revision: 489126
- new version 1.2.1
- rediff Patch0
- add Patch1 from upstream to fix a database upgrade problem

* Fri Dec 18 2009 Jérôme Brenier <incubusss@mandriva.org> 1.2.0-3mdv2010.1
+ Revision: 479861
- fix SIGHUP syntax in the initscript (bluca)
- provide a logrotate file adapted to mandriva (spotted by bluca)
- add pidfile directory (thanks to bluca)
- drop /etc/default/mumble-server
- add an option not to build clients (thanks to bluca)

* Mon Dec 14 2009 Jérôme Brenier <incubusss@mandriva.org> 1.2.0-2mdv2010.1
+ Revision: 478633
- revert to make -j2
- BR celt-devel >= 0.7.0
- re-enable parallel compilation

* Fri Dec 11 2009 Jérôme Brenier <incubusss@mandriva.org> 1.2.0-1mdv2010.1
+ Revision: 476275
- final version 1.2.0

* Wed Dec 02 2009 Jérôme Brenier <incubusss@mandriva.org> 1.2.0-0.beta2.1mdv2010.1
+ Revision: 472480
- update to 1.2.0~beta2

* Wed Nov 18 2009 Jérôme Brenier <incubusss@mandriva.org> 1.2.0-0.beta1.1mdv2010.1
+ Revision: 467286
- BuildRequires : avahi-compat-libdns_sd-devel
- new version 1.2.0~beta1
- rediff P0
- new subpackage mumble11x (client compatible with 1.1.x servers)
- build with now available speech-dispatcher
- build with celt (BR celt-devel)
- BR protobuf-devel and protobuf-compiler
- liblink.so now in %%{_libdir}/mumble
- fix icon

  + Michael Scherer <misc@mandriva.org>
    - mark /etc/mumble-server.ini as a config file

* Thu May 28 2009 Jérôme Brenier <incubusss@mandriva.org> 1.1.8-1mdv2010.0
+ Revision: 380670
- add a BR on libogg-devel
- add a missing Requires (plugins subpackage)
- update to new version 1.1.8
- put plugins into a plugins sub-package instead of a lib one
- add Provides/Obsoletes on former sub-packages
- str fmt patch rediffed
- fixsegfault patch dropped (merged in new sources)
- fix license

* Fri Mar 13 2009 Stéphane Téletchéa <steletch@mandriva.org> 1.1.7-2mdv2009.1
+ Revision: 354526
- Add segfault fix, fixes bug #48490

* Thu Feb 26 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.7-1mdv2009.1
+ Revision: 345270
- spec clean
- update to new version 1.1.7
- use complete new spec file from incubusss, with some modifications made by me (mdvbz #40902)
- add sources
- add source and spec file
- Created package structure for mumble.

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

  + Michael Scherer <misc@mandriva.org>
    - add missing BuildRequires

